Stan Math Library: stan/math/rev/core/vv_vari.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

vv_vari.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_REV_CORE_VV_VARI_HPP
2 #define STAN_MATH_REV_CORE_VV_VARI_HPP
3
4 #include <stan/math/rev/core/vari.hpp>
5
6 namespace stan {
7 namespace math {
8
9 class op_vv_vari : public vari {
10 protected:
11 vari* avi_;
12 vari* bvi_;
13 public:
14 op_vv_vari(double f, vari* avi, vari* bvi):
15 vari(f),
16 avi_(avi),
17 bvi_(bvi) {
18 }
19 };
20
21 }
22 }
23 #endif
vari.hpp
stan
Definition: log_sum_exp.hpp:8
stan::math::op_vv_vari::op_vv_vari
op_vv_vari(double f, vari *avi, vari *bvi)
Definition: vv_vari.hpp:14
stan::math::vari
The variable implementation base class.
Definition: vari.hpp:30
stan::math::op_vv_vari::bvi_
vari * bvi_
Definition: vv_vari.hpp:12
stan::math::op_vv_vari::avi_
vari * avi_
Definition: vv_vari.hpp:11
stan::math::op_vv_vari
Definition: vv_vari.hpp:9

[ Stan Home Page ] © 2011–2016, Stan Development Team.